SignedBoxedInt

Struct SignedBoxedInt 

struct SignedBoxedInt {
    sign: Choice,
    magnitude: BoxedUint,
}
A Uint which carries a separate sign in order to maintain the same range.

Fields

sign: Choicemagnitude: BoxedUint

Implementations

Source

impl SignedBoxedInt

pub fn zero_with_precision(bits_precision: u32) -> Self

pub const fn from_uint(uint: BoxedUint) -> Self

Construct a new SignedInt from a Uint.

pub fn from_uint_with_precision(uint: &BoxedUint, bits_precision: u32) -> Self

Construct a new SignedInt from a Uint.

pub const fn from_uint_sign(magnitude: BoxedUint, sign: Choice) -> Self

Construct a new SignedInt from a Uint and a sign flag.

pub const fn magnitude(&self) -> &BoxedUint

Obtain the magnitude of the SignedInt, i.e. its absolute value.

pub fn is_nonzero(&self) -> Choice

Determine if the SignedInt is non-zero.

pub fn is_zero_vartime(&self) -> bool

Determine if the SignedInt is zero in variable time.

pub const fn is_negative(&self) -> Choice

Determine if the SignedInt is negative. Note: -0 is representable in this type, so it may be necessary to check self.is_nonzero() as well.

pub fn lowest(&self) -> i64

Extract the lowest 63 bits and convert to its signed representation.

pub(crate) fn lincomb_int<const RHS: usize>( a: &Self, b: &Self, c: &Int<RHS>, d: &Int<RHS>, ) -> Self

Compute the linear combination a•b + c•d, returning a widened result.

pub(crate) fn lincomb_int_reduce_shift<const S: usize>( a: &Self, b: &Self, c: &Int<S>, d: &Int<S>, shift: u32, ) -> Self

Compute the linear combination a•b + c•d, and shift the result shift bits to the right, returning a signed value in the same range as the SignedInt inputs.

pub(crate) fn lincomb_int_reduce_shift_mod<const S: usize>( a: &Self, b: &Self, c: &Int<S>, d: &Int<S>, shift: u32, m: &BoxedUint, mi: Uint<S>, ) -> Self

Compute the linear combination a•b + c•d, and shift the result shift bits to the right modulo m, returning a signed value in the same range as the SignedInt inputs.

fn norm(&self, f_sign: Choice, m: &BoxedUint) -> BoxedUint

Normalize the value to a BoxedUint in the range [0, m).